(define (domain transport)
(:requirements :typing :numeric-fluents :action-costs )
(:types
	location - object
	target - object
	locatable - object
	vehicle - locatable
	package - locatable
	capacity-number - object
	softgoalorder
)
(:predicates
	(road ?l1 - location ?l2 - location )
	(at ?x - locatable ?v - location )
	(in ?x - package ?v - vehicle )
	(has-petrol-station ?l - location )
	(capacity ?v - vehicle ?s1 - capacity-number )
	(capacity-predecessor ?s1 - capacity-number ?s2 - capacity-number )
	(next-softgoal ?v0 - softgoalorder ?v1 - softgoalorder )
	(current-softgoal ?v0 - softgoalorder )
	(normal-mode )
	(softgoal-mode )
	(at-softgoal ?v0 - locatable ?v1 - location )
	(at-softgoal-order ?v0 - locatable ?v1 - location ?v2 - softgoalorder )
)
(:functions
	(road-length ?l1 - location ?l2 - location )
	(fuel-demand ?l1 - location ?l2 - location )
	(fuel-left ?v - vehicle )
	(fuel-max ?v - vehicle )
	(total-cost )
	(at-softgoal-reward ?v0 - locatable ?v1 - location )
)
(:action drive
	:parameters (?v - vehicle ?l1 - location ?l2 - location )
	:precondition (and
		(at ?v ?l1 )
		(road ?l1 ?l2 )
		(>= (fuel-left ?v )(fuel-demand ?l1 ?l2 ))
		(normal-mode )
)
	:effect (and
		(not (at ?v ?l1 ))
		(at ?v ?l2 )
		(decrease (fuel-left ?v ) (fuel-demand ?l1 ?l2 ) )
		(increase (total-cost ) (road-length ?l1 ?l2 ) )
)
)

(:action pick-up
	:parameters (?v - vehicle ?l - location ?p - package ?s1 - capacity-number ?s2 - capacity-number )
	:precondition (and
		(at ?v ?l )
		(at ?p ?l )
		(capacity-predecessor ?s1 ?s2 )
		(capacity ?v ?s2 )
		(normal-mode )
)
	:effect (and
		(not (at ?p ?l ))
		(in ?p ?v )
		(capacity ?v ?s1 )
		(not (capacity ?v ?s2 ))
		(increase (total-cost ) 1 )
)
)

(:action drop
	:parameters (?v - vehicle ?l - location ?p - package ?s1 - capacity-number ?s2 - capacity-number )
	:precondition (and
		(at ?v ?l )
		(in ?p ?v )
		(capacity-predecessor ?s1 ?s2 )
		(capacity ?v ?s1 )
		(normal-mode )
)
	:effect (and
		(not (in ?p ?v ))
		(at ?p ?l )
		(capacity ?v ?s2 )
		(not (capacity ?v ?s1 ))
		(increase (total-cost ) 1 )
)
)

(:action refuel
	:parameters (?v - vehicle ?l - location )
	:precondition (and
		(at ?v ?l )
		(has-petrol-station ?l )
		(normal-mode )
)
	:effect (and
		(assign (fuel-left ?v ) (fuel-max ?v ) )
		(increase (total-cost ) 10 )
)
)

(:action at-softgoal-collect
	:parameters (?v0 - locatable ?v1 - location ?v2 - softgoalorder ?v3 - softgoalorder )
	:precondition (and
		(next-softgoal ?v2 ?v3 )
		(current-softgoal ?v2 )
		(at-softgoal-order ?v0 ?v1 ?v2 )
		(softgoal-mode )
		(at ?v0 ?v1 )
)
	:effect (and
		(at-softgoal ?v0 ?v1 )
		(current-softgoal ?v3 )
		(not (current-softgoal ?v2 ))
)
)

(:action at-softgoal-forgo
	:parameters (?v0 - locatable ?v1 - location ?v2 - softgoalorder ?v3 - softgoalorder )
	:precondition (and
		(softgoal-mode )
		(next-softgoal ?v2 ?v3 )
		(current-softgoal ?v2 )
		(at-softgoal-order ?v0 ?v1 ?v2 )
		(not (at ?v0 ?v1 ))
)
	:effect (and
		(at-softgoal ?v0 ?v1 )
		(current-softgoal ?v3 )
		(not (current-softgoal ?v2 ))
		(increase (total-cost ) (at-softgoal-reward ?v0 ?v1 ) )
)
)

(:action begin-softgoal-mode
	:parameters ()
	:precondition (and
		(normal-mode )
)
	:effect (and
		(not (normal-mode ))
		(softgoal-mode )
)
)

)
